@@ -14,8 +14,12 @@ class DictLoader(Loader):
         """Load the configuration from a dict"""
         return conf
 
+    async def a_loading(self, conf: Any, ignore_nonexist: bool) -> Dict[str, Any]:
+        """Asynchronously load the configuration from a dict"""
+        return conf
 
-class DictsLoader(NoConvertingPathMixin, DictLoader):
+
+class DictsLoader(NoConvertingPathMixin, DictLoader):  # type: ignore[misc]
     """Dict string loader"""
 
     def loading(self, conf: Any, ignore_nonexist: bool) -> Dict[str, Any]:
